from wagtail.core import blocks

from .base_field_block import BaseFieldBlock


class MultiSelectFieldBlock(BaseFieldBlock):

    choices = blocks.ListBlock(
        blocks.TextBlock(
            required=True,
            icon='extraicons--heading-icon',
        ),
    )

    html = None

    display_checkbox_label = None

    placeholder = None

    empty_label = None

    max_length = None

    display_side_by_side = None

    class Meta:
        form_classname = 'waf--field'
        icon = 'extraicons--multi-select'



from wagtail.contrib.forms.models import AbstractForm

from .abstract_advanced_form_mixin import AbstractAdvancedFormMixin


class AbstractAdvancedForm(AbstractAdvancedFormMixin, AbstractForm):

    settings_panels = AbstractAdvancedFormMixin.settings_panels

    class Meta:
        abstract = True



from django.forms import CheckboxInput as DjangoCheckboxInput


class CheckboxInput(DjangoCheckboxInput):

    def __init__(self, display_checkbox_label=False, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.display_checkbox_label = display_checkbox_label

    def get_context(self, *args, **kwargs):

        context = super().get_context(*args, **kwargs)

        context['widget'].update({
            'display_checkbox_label': self.display_checkbox_label,
        })

        return context



from wagtail.core import blocks

from .base_field_block import BaseFieldBlock


class CheckboxFieldBlock(BaseFieldBlock):

    choices = None

    help_text = blocks.CharBlock(
        max_length=255,
        required=False,
    )

    html = None

    default_value = None

    display_side_by_side = None

    empty_label = None

    max_length = None

    placeholder = None


    class Meta:

        form_classname = 'waf--field'
        icon = 'extraicons--checkbox'



from django.template.loader import render_to_string
from wagtail.core import blocks


class BaseStaticBlock(blocks.StaticBlock):
    """
    This is used instead of blocks.StaticBlock to control markup in admin and apply styling
    """
    def render_form(self, value, prefix='', errors=None):
        return render_to_string('wagtail_advanced_form_builder/admin/blocks/base_static_block.html', {
            'name': self.name,
            'text': self.meta.help_text,
            'classes': self.meta.form_classname,
        })
